@@ -20,28 +20,27 @@
  *
  */
 
+#include "mainwindow.h"
+#include "batchextract.h"
+#include "kerfuffle/addtoarchive.h"
+
+#include <KAboutData>
 #include <KApplication>
 #include <KCmdLineArgs>
 #include <KDebug>
 #include <KLocale>
-#include <KAboutData>
+
 #include <QByteArray>
 #include <QFileInfo>
-#include <QEventLoop>
 
-#include "mainwindow.h"
-#include "kerfuffle/batchextract.h"
-#include "kerfuffle/addtoarchive.h"
-
-using Kerfuffle::BatchExtract;
 using Kerfuffle::AddToArchive;
 
 int main(int argc, char **argv)
 {
     KAboutData aboutData("ark", 0, ki18n("Ark"),
-                         "2.13", ki18n("KDE Archiving tool"),
+                         "2.16", ki18n("KDE Archiving tool"),
                          KAboutData::License_GPL,
-                         ki18n("(c) 1997-2008, The Various Ark Developers"),
+                         ki18n("(c) 1997-2010, The Various Ark Developers"),
                          KLocalizedString(),
                          "http://utils.kde.org/projects/ark"
                         );
@@ -49,6 +48,9 @@ int main(int argc, char **argv)
     aboutData.addAuthor(ki18n("Harald Hvaal"),
                         ki18n("Maintainer"),
                         "haraldhv@stud.ntnu.no");
+    aboutData.addAuthor(ki18n("Raphael Kubo da Costa"),
+                        ki18n("Maintainer"),
+                        "kubito@gmail.com");
     aboutData.addAuthor(ki18n("Henrique Pinto"),
                         ki18n("Former Maintainer"),
                         "henrique.pinto@kdemail.net");
@@ -84,7 +86,7 @@ int main(int argc, char **argv)
                         ki18n("bkisofs code"),
                         QByteArray(),
                         "http://littlesvr.ca/misc/contactandrew.php");
-    aboutData.setProgramIconName("utilities-file-archiver");
+    aboutData.setProgramIconName(QLatin1String( "utilities-file-archiver" ));
 
     KCmdLineArgs::init(argc, argv, &aboutData);
     KCmdLineOptions option;
@@ -99,7 +101,7 @@ int main(int argc, char **argv)
     option.add(":", ki18n("Options for batch extraction:"));
     option.add("b").add("batch", ki18n("Use the batch interface instead of the usual dialog. This option is implied if more than one url is specified."));
     option.add("e").add("autodestination", ki18n("The destination argument will be set to the path of the first file supplied."));
-    option.add("a").add("autosubfolder", ki18n("Archive contents will be read, and if detected to not be a single folder archive, a subfolder by the name of the archive will be created."));
+    option.add("a").add("autosubfolder", ki18n("Archive contents will be read, and if detected to not be a single folder archive, a subfolder with the name of the archive will be created."));
     KCmdLineArgs::addCmdLineOptions(option);
     KCmdLineArgs::addTempFileOption();
 
@@ -128,7 +130,7 @@ int main(int argc, char **argv)
 
         if (args->isSet("add") || args->isSet("add-to")) {
             AddToArchive *addToArchiveJob = new AddToArchive;
-            application.connect(addToArchiveJob, SIGNAL(result(KJob*)), SLOT(quit()));
+            application.connect(addToArchiveJob, SIGNAL(result(KJob*)), SLOT(quit()), Qt::QueuedConnection);
 
             if (args->isSet("changetofirstpath")) {
                 addToArchiveJob->setChangeToFirstPath(true);
@@ -155,28 +157,26 @@ int main(int argc, char **argv)
 
             addToArchiveJob->start();
         } else if (args->isSet("batch")) {
-            //once the job has been started this interface can be safely
-            //deleted
             BatchExtract *batchJob = new BatchExtract;
-            application.connect(batchJob, SIGNAL(result(KJob*)), SLOT(quit()));
+            application.connect(batchJob, SIGNAL(result(KJob*)), SLOT(quit()), Qt::QueuedConnection);
 
             for (int i = 0; i < args->count(); ++i) {
                 batchJob->addInput(args->url(i));
             }
 
             if (args->isSet("autosubfolder")) {
-                kDebug(1601) << "Setting autosubfolder";
+                kDebug() << "Setting autosubfolder";
                 batchJob->setAutoSubfolder(true);
             }
 
             if (args->isSet("autodestination")) {
                 QString autopath = QFileInfo(args->url(0).path()).path();
-                kDebug(1601) << "By autodestination, setting path to " << autopath;
+                kDebug() << "By autodestination, setting path to " << autopath;
                 batchJob->setDestinationFolder(autopath);
             }
 
             if (args->isSet("destination")) {
-                kDebug(1601) << "Setting destination to " << args->getOption("destination");
+                kDebug() << "Setting destination to " << args->getOption("destination");
                 batchJob->setDestinationFolder(args->getOption("destination"));
             }
 
@@ -205,6 +205,6 @@ int main(int argc, char **argv)
         }
     }
 
-    kDebug(1601) << "Entering application loop";
+    kDebug() << "Entering application loop";
     return application.exec();
 }
