@@ -44,10 +44,11 @@ InfoPanel::InfoPanel(ArchiveModel *model, QWidget *parent)
 
     // Make the file name font bigger than the rest
     QFont fnt = fileName->font();
-    if (fnt.pointSize() > -1)
+    if (fnt.pointSize() > -1) {
         fnt.setPointSize(fnt.pointSize() + 1);
-    else
+    } else {
         fnt.setPixelSize(fnt.pixelSize() + 3);
+    }
     fileName->setFont(fnt);
 
     updateWithDefaults();
@@ -59,9 +60,9 @@ InfoPanel::~InfoPanel()
 
 void InfoPanel::updateWithDefaults()
 {
-    iconLabel->setPixmap(KIconLoader::global()->loadIcon("utilities-file-archiver", KIconLoader::Desktop, KIconLoader::SizeHuge));
+    iconLabel->setPixmap(KIconLoader::global()->loadIcon(QLatin1String( "utilities-file-archiver" ), KIconLoader::Desktop, KIconLoader::SizeHuge));
 
-    QString currentFileName = prettyFileName();
+    const QString currentFileName = prettyFileName();
 
     if (currentFileName.isEmpty()) {
         fileName->setText(i18n("No archive loaded"));
@@ -74,7 +75,7 @@ void InfoPanel::updateWithDefaults()
     hideActions();
 }
 
-QString InfoPanel::prettyFileName()
+QString InfoPanel::prettyFileName() const
 {
     if (m_prettyFileName.isEmpty()) {
         if (m_model->archive()) {
@@ -101,7 +102,7 @@ void InfoPanel::setIndex(const QModelIndex& index)
         KMimeType::Ptr mimeType;
 
         if (entry[ IsDirectory ].toBool()) {
-            mimeType = KMimeType::mimeType("inode/directory");
+            mimeType = KMimeType::mimeType(QLatin1String( "inode/directory" ));
         } else {
             mimeType = KMimeType::findByPath(entry[ FileName ].toString(), 0, true);
         }
@@ -120,8 +121,8 @@ void InfoPanel::setIndex(const QModelIndex& index)
             }
         }
 
-        QStringList nameParts = entry[ FileName ].toString().split('/', QString::SkipEmptyParts);
-        QString name = (nameParts.count() > 0) ? nameParts.last() : entry[ FileName ].toString();
+        const QStringList nameParts = entry[ FileName ].toString().split(QLatin1Char( '/' ), QString::SkipEmptyParts);
+        const QString name = (nameParts.count() > 0) ? nameParts.last() : entry[ FileName ].toString();
         fileName->setText(name);
 
         metadataLabel->setText(metadataTextFor(index));
@@ -136,7 +137,7 @@ void InfoPanel::setIndexes(const QModelIndexList &list)
     } else if (list.size() == 1) {
         setIndex(list[ 0 ]);
     } else {
-        iconLabel->setPixmap(KIconLoader::global()->loadIcon("utilities-file-archiver", KIconLoader::Desktop, KIconLoader::SizeHuge));
+        iconLabel->setPixmap(KIconLoader::global()->loadIcon(QLatin1String( "utilities-file-archiver" ), KIconLoader::Desktop, KIconLoader::SizeHuge));
         fileName->setText(i18np("One file selected", "%1 files selected", list.size()));
         quint64 totalSize = 0;
         foreach(const QModelIndex& index, list) {
@@ -180,7 +181,7 @@ QString InfoPanel::metadataTextFor(const QModelIndex &index)
     KMimeType::Ptr mimeType;
 
     if (entry[ IsDirectory ].toBool()) {
-        mimeType = KMimeType::mimeType("inode/directory");
+        mimeType = KMimeType::mimeType(QLatin1String( "inode/directory" ));
     } else {
         mimeType = KMimeType::findByPath(entry[ FileName ].toString(), 0, true);
     }
