@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2002 Jean-Baptiste Mardelle <bj@altern.org>
- * Copyright (C) 2007,2008 Rolf Eike Beer <kde@opensource.sf-tec.de>
+ * Copyright (C) 2007,2008,2009,2010 Rolf Eike Beer <kde@opensource.sf-tec.de>
  */
 
 /***************************************************************************
@@ -63,10 +63,12 @@ private:
 	QString m_log;
 };
 
+//krazy:cond=strings
 static bool isUtf8Lang(const QByteArray &lc)
 {
 	return lc.endsWith("UTF-8");
 }
+//krazy:endcond=strings
 
 KGpgTextInterfacePrivate::KGpgTextInterfacePrivate()
 	: m_ok(false),
@@ -93,7 +95,7 @@ KGpgTextInterfacePrivate::KGpgTextInterfacePrivate()
 				m_consoleUtf8 = isUtf8Lang(lang);
 		}
 	}
-	
+
 }
 
 void
@@ -132,7 +134,7 @@ KGpgTextInterfacePrivate::gpgPassphrase()
 	if (m_userIDs.isEmpty())
 		s = i18n("[No user id found]");
 	else
-		s = m_userIDs.join(i18n(" or "));
+		s = m_userIDs.join( i18n(" or " ));
 
 	QString passdlgmessage;
 	if (m_anonymous)
@@ -158,12 +160,12 @@ KGpgTextInterfacePrivate::gpgPassphrase()
 void
 KGpgTextInterfacePrivate::signFile(const KUrl &file)
 {
-	*m_process << "--command-fd=0" << "-u" << m_signID.simplified().toLocal8Bit();
+	*m_process << QLatin1String( "--command-fd=0" ) << QLatin1String( "-u" ) << m_signID;
 
 	*m_process << m_gpgopts;
 
-	if (m_gpgopts.contains("--detach-sign") && !m_gpgopts.contains("--output"))
-		*m_process << "--output" << file.path() + ".sig";
+	if (m_gpgopts.contains(QLatin1String( "--detach-sign" )) && !m_gpgopts.contains( QLatin1String( "--output" )))
+		*m_process << QLatin1String( "--output" ) << file.path() + QLatin1String( ".sig" );
 	*m_process << file.path();
 
 	m_process->start();
@@ -188,7 +190,7 @@ KGpgTextInterface::KGpgTextInterface(QObject *parent)
 	: QObject(parent), d(new KGpgTextInterfacePrivate)
 {
 	d->m_process = new GPGProc(this);
-	*d->m_process << "--status-fd=1" << "--command-fd=0";
+	*d->m_process << QLatin1String( "--status-fd=1" ) << QLatin1String( "--command-fd=0" );
 
 }
 
@@ -205,20 +207,20 @@ KGpgTextInterface::encryptText(const QString &text, const QStringList &userids,
 	if (codec->canEncode(text))
 		d->m_message = text;
 	else
-		d->m_message = text.toUtf8();
+		d->m_message = QLatin1String( text.toUtf8() );
 
 	*d->m_process << options;
 
 	if (userids.isEmpty()) {
-		*d->m_process << "-c";
+		*d->m_process << QLatin1String( "-c" );
 	} else {
-		*d->m_process << "-e";
-		for (QStringList::ConstIterator it = userids.constBegin(); it != userids.constEnd(); ++it)
-			*d->m_process << "--recipient" << *it;
+		*d->m_process << QLatin1String( "-e" );
+		foreach (const QString &uid, userids)
+			*d->m_process << QLatin1String( "--recipient" ) << uid;
 	}
 
-	connect(d->m_process, SIGNAL(readReady(GPGProc *)), this, SLOT(encryptTextProcess()));
-	connect(d->m_process, SIGNAL(processExited(GPGProc *)), this, SLOT(encryptTextFin()));
+	connect(d->m_process, SIGNAL(readReady()), this, SLOT(encryptTextProcess()));
+	connect(d->m_process, SIGNAL(processExited()), this, SLOT(encryptTextFin()));
 	d->m_process->start();
 }
 
@@ -235,14 +237,14 @@ KGpgTextInterface::encryptTextProcess()
 				d->m_process->write(d->m_message.toAscii());
 				d->m_process->closeWriteChannel();
 				d->m_message.clear();
-			} else if (line.contains("passphrase.enter")) {
+			} else if (line.contains( QLatin1String( "passphrase.enter" ))) {
 				if (d->symPassphrase()) {
 					d->m_message.clear();
 					return;
 				}
 			}
 		} else {
-			d->m_message += line + '\n';
+			d->m_message += line + QLatin1Char( '\n' );
 		}
 	}
 }
@@ -250,108 +252,7 @@ KGpgTextInterface::encryptTextProcess()
 void
 KGpgTextInterface::encryptTextFin()
 {
-	emit txtEncryptionFinished(d->m_message.trimmed(), this);
-}
-
-void
-KGpgTextInterface::decryptText(const QString &text, const QStringList &options)
-{
-	*d->m_process << options;
-
-	*d->m_process << "-d";
-
-	d->m_process->setOutputChannelMode(KProcess::SeparateChannels);
-	connect(d->m_process, SIGNAL(readyReadStandardError()), this, SLOT(decryptTextStdErr()));
-	connect(d->m_process, SIGNAL(lineReadyStandardOutput()), this, SLOT(decryptTextStdOut()));
-	connect(d->m_process, SIGNAL(processExited(GPGProc *)), this, SLOT(decryptTextFin()));
-	d->m_process->start();
-
-	d->m_process->write(text.toAscii());
-}
-
-void
-KGpgTextInterface::decryptTextStdErr()
-{
-	QByteArray a;
-
-	while (d->m_process->readLineStandardError(&a))
-		d->appendLog(a + '\n');
-}
-
-//krazy:cond=strings
-void
-KGpgTextInterface::decryptTextStdOut()
-{
-	QByteArray line;
-
-	while (!line.isEmpty() || d->m_process->readLineStandardOutput(&line)) {
-		if (line.startsWith("[GNUPG:] ")) {
-			line.remove(0, 9);
-			if (line.startsWith("USERID_HINT")) {
-				d->updateIDs(line);
-			} else if (line.startsWith("ENC_TO")) {
-				if (line.contains("0000000000000000"))
-					d->m_anonymous = true;
-			} else if (line.startsWith("GET_")) {
-				if ((line.contains("passphrase.enter"))) {
-					if (d->gpgPassphrase())
-						return;
-				} else {
-					d->m_process->write("quit\n");
-				}
-			} else if (line.startsWith("BEGIN_DECRYPTION")) {
-				d->m_process->closeWriteChannel();
-			} else if (line.startsWith("PLAINTEXT_LENGTH")) {
-				d->m_textlength = line.mid(16).toInt();
-			} else if (line.startsWith("DECRYPTION_OKAY")) {
-				d->m_ok = true;
-				// this happens if the encrypted text does not end with '\n'
-				// 25 is strlen('[GNUPG:] DECRYPTION_OKAY')
-				if (d->m_tmpmessage.endsWith("[GNUPG:] DECRYPTION_OKAY\n"))
-					d->m_tmpmessage.chop(25);
-			} else if (line.startsWith("BADMDC")) {
-				d->m_badmdc = true;
-			} else if (line.startsWith("BAD_PASSPHRASE")) {
-				d->m_step--;
-			} else if (line.startsWith("END_DECRYPTION")) {
-				// workaround for GnuPG weirdness: DECRYPTION_OKAY is
-				// not written if message is signed *and* encrypted
-				if (!d->m_forcefail)
-					d->m_ok = true;
-			} else if (line.startsWith("DECRYPTION_FAILED")) {
-				d->m_ok = false;
-				d->m_forcefail = true;
-			}
-			line.clear();
-		} else {
-			if (d->m_textlength == -1) {
-				d->m_tmpmessage.append(line + '\n');
-				line.clear();
-			} else if (d->m_textlength < line.length()) {
-				d->m_tmpmessage.append(line.left(d->m_textlength));
-				line.remove(0, d->m_textlength);
-				d->m_textlength = 0;
-			} else {
-				d->m_tmpmessage.append(line + '\n');
-				d->m_textlength -= line.length() + 1;
-				line.clear();
-			}
-		}
-	}
-}
-//krazy:endcond=strings
-
-void
-KGpgTextInterface::decryptTextFin()
-{
-	if ((d->m_ok) && (!d->m_badmdc)) {
-		emit txtDecryptionFinished(d->m_tmpmessage, this);
-	} else if (d->m_badmdc) {
-		KMessageBox::sorry(0, i18n("Bad MDC detected. The encrypted text has been manipulated."));
-		emit txtDecryptionFailed(d->log(), this);
-	} else {
-		emit txtDecryptionFailed(d->log(), this);
-	}
+	emit txtEncryptionFinished(d->m_message.trimmed());
 }
 
 void
@@ -361,14 +262,14 @@ KGpgTextInterface::signText(const QString &text, const QString &userid, const QS
 	if (codec->canEncode(text))
 		d->m_message = text;
 	else
-		d->m_message = text.toUtf8();
+		d->m_message =QLatin1String( text.toUtf8() );
 
 	*d->m_process << options;
 
-	*d->m_process << "--clearsign" << "-u" << userid;
+	*d->m_process << QLatin1String( "--clearsign" ) << QLatin1String( "-u" ) << userid;
 
 	connect(d->m_process, SIGNAL(lineReadyStandardOutput()), this, SLOT(signTextProcess()));
-	connect(d->m_process, SIGNAL(processExited(GPGProc *)), this, SLOT(signTextFin()));
+	connect(d->m_process, SIGNAL(processExited()), this, SLOT(signTextFin()));
 	d->m_process->start();
 }
 
@@ -380,22 +281,22 @@ KGpgTextInterface::signTextProcess()
 
 	while (d->m_process->readLineStandardOutput(&line)) {
 		if (line.startsWith("[GNUPG:]")) {
-			if (line.contains("USERID_HINT")) {
+			if (line.contains( "USERID_HINT" )) {
 				d->updateIDs(line);
-			} else if (line.contains("BAD_PASSPHRASE")) {
-				d->m_message.fill('x');
+			} else if (line.contains( "BAD_PASSPHRASE" )) {
+				d->m_message.fill(QLatin1Char( 'x' ));
 				d->m_message.clear();
 				d->m_badpassword = true;
-			} else if (line.contains("GOOD_PASSPHRASE")) {
+			} else if (line.contains( "GOOD_PASSPHRASE" )) {
 				d->m_process->write(d->m_message.toAscii());
 				d->m_process->closeWriteChannel();
 				d->m_message.clear();
-			} else if (line.contains("passphrase.enter")) {
+			} else if (line.contains( "passphrase.enter" )) {
 				if (d->gpgPassphrase())
 					return;
 			}
-		} else 
-			d->m_message += line + '\n';
+		} else
+			d->m_message +=QLatin1String( line ) + QLatin1Char( '\n' );
 	}
 }
 //krazy:endcond=strings
@@ -404,12 +305,11 @@ void
 KGpgTextInterface::signTextFin()
 {
 	if (d->m_badpassword) {
-		emit txtSigningFailed(d->m_message, this);
 		d->m_message.clear();
 	} else if (!d->m_message.isEmpty()) {
-		emit txtSigningFinished(d->m_message.trimmed(), this);
+		emit txtSigningFinished(d->m_message.trimmed());
 	} else {
-		emit txtSigningFinished(QString(), this);
+		emit txtSigningFinished(QString());
 	}
 }
 
@@ -420,12 +320,12 @@ KGpgTextInterface::verifyText(const QString &text)
 	if (codec->canEncode(text))
 		d->m_message = text;
 	else
-		d->m_message = text.toUtf8();
+		d->m_message = QLatin1String( text.toUtf8() );
 
-	*d->m_process << "--verify";
+	*d->m_process << QLatin1String( "--verify" );
 
-	connect(d->m_process, SIGNAL(readReady(GPGProc *)), this, SLOT(readVerify()));
-	connect(d->m_process, SIGNAL(processExited(GPGProc *)), this, SLOT(verifyTextFin()));
+	connect(d->m_process, SIGNAL(readReady()), this, SLOT(readVerify()));
+	connect(d->m_process, SIGNAL(processExited()), this, SLOT(verifyTextFin()));
 	d->m_process->start();
 
 	d->m_process->write(d->m_message.toAscii());
@@ -437,12 +337,12 @@ void
 KGpgTextInterface::verifyTextFin()
 {
 	if (d->m_signmiss) {
-		emit txtVerifyMissingSignature(d->m_signID, this);
+		emit txtVerifyMissingSignature(d->m_signID);
 	} else {
 		if (d->m_signID.isEmpty())
-		d->m_signID = i18n("No signature found.");
+			d->m_signID = i18n("No signature found.");
 
-		emit txtVerifyFinished(d->m_signID, d->m_message, this);
+		emit txtVerifyFinished(d->m_signID, d->m_message);
 	}
 }
 
@@ -453,24 +353,23 @@ KGpgTextInterface::encryptFile(const QStringList &encryptkeys, const KUrl &srcur
 
 	*d->m_process << options;
 
-	if (!options.contains("--output"))
-		*d->m_process << "--output" << desturl.path();
+	if (!options.contains( QLatin1String( "--output" )))
+		*d->m_process << QLatin1String( "--output" ) << desturl.path();
 
 	if (!symetrical) {
-		*d->m_process << "-e";
-		for (QStringList::ConstIterator it = encryptkeys.constBegin(); it != encryptkeys.constEnd(); ++it)
-		*d->m_process << "--recipient" << *it;
+		*d->m_process << QLatin1String( "-e" );
+		foreach (const QString &enckey, encryptkeys)
+			*d->m_process << QLatin1String( "--recipient" ) << enckey;
 	} else
-		*d->m_process << "-c";
+		*d->m_process << QLatin1String( "-c" );
 
 	*d->m_process << srcurl.path();
 
-	connect(d->m_process, SIGNAL(readReady(GPGProc *)), this, SLOT(fileReadEncProcess()));
-	connect(d->m_process, SIGNAL(processExited(GPGProc *)), this, SLOT(fileEncryptFin()));
+	connect(d->m_process, SIGNAL(readReady()), this, SLOT(fileReadEncProcess()));
+	connect(d->m_process, SIGNAL(processExited()), this, SLOT(fileEncryptFin()));
 	d->m_process->start();
 }
 
-// TODO : there is a bug when we want to encrypt a file
 void
 KGpgTextInterface::fileReadEncProcess()
 {
@@ -479,24 +378,23 @@ KGpgTextInterface::fileReadEncProcess()
 	while (d->m_process->readln(line) >= 0) {
 		kDebug(2100) << line ;
 		if (line.startsWith(QLatin1String("[GNUPG:]"))) {
-			if (line.contains("BEGIN_ENCRYPTION")) {
-				emit processstarted(d->m_file.path());
-			} else if (line.contains("GET_" )) {
-				if (line.contains("openfile.overwrite.okay")) {
+			if (line.contains( QLatin1String( "BEGIN_ENCRYPTION" ))) {
+			} else if (line.contains( QLatin1String( "GET_" ) )) {
+				if (line.contains( QLatin1String( "openfile.overwrite.okay" ))) {
 					d->m_process->write("Yes\n");
-				} else if (line.contains("passphrase.enter")) {
+				} else if (line.contains( QLatin1String( "passphrase.enter" ))) {
 					if (d->symPassphrase())
 						return;
 				} else {
 					d->m_process->write("quit\n");
 				}
-			} else if (line.contains("END_ENCRYPTION")) {
+			} else if (line.contains( QLatin1String( "END_ENCRYPTION" ))) {
 				d->m_ok = true;
 			} else {
-				d->m_message += line + '\n';
+				d->m_message += line + QLatin1Char( '\n' );
 			}
 		} else {
-			d->m_message += line + '\n';
+			d->m_message += line + QLatin1Char( '\n' );
 		}
 	}
 }
@@ -505,26 +403,9 @@ void
 KGpgTextInterface::fileEncryptFin()
 {
 	if (d->m_ok)
-		emit fileEncryptionFinished(d->m_file, this);
+		emit fileEncryptionFinished(d->m_file);
 	else
-		emit errorMessage(d->m_message, this);
-}
-
-// decrypt file to text
-void
-KGpgTextInterface::KgpgDecryptFileToText(const KUrl &srcUrl, const QStringList &options)
-{
-	*d->m_process << "--no-batch" << "-o" << "-";
-
-	*d->m_process << options;
-
-	*d->m_process << "-d" << srcUrl.path();
-
-	d->m_process->setOutputChannelMode(KProcess::SeparateChannels);
-	connect(d->m_process, SIGNAL(readyReadStandardError()), this, SLOT(decryptTextStdErr()));
-	connect(d->m_process, SIGNAL(readReady(GPGProc *)), this, SLOT(decryptTextStdOut()));
-	connect(d->m_process, SIGNAL(processExited(GPGProc *)), this, SLOT(decryptTextFin()));
-	d->m_process->start();
+		emit errorMessage(d->m_message);
 }
 
 void
@@ -532,14 +413,14 @@ KGpgTextInterface::decryptFile(const KUrl &src, const KUrl &dest, const QStringL
 {
 	d->m_file = src;
 
-	*d->m_process << "--no-verbose" << "--no-greeting";
+	*d->m_process << QLatin1String( "--no-verbose" ) << QLatin1String( "--no-greeting" );
 
 	*d->m_process << options;
 
 	d->m_dest = dest;
 	if (!dest.fileName().isEmpty())
-		*d->m_process << "-o" << dest.path();
-	*d->m_process << "-d" << src.path();
+		*d->m_process << QLatin1String( "-o" ) << dest.path();
+	*d->m_process << QLatin1String( "-d" ) << src.path();
 
 	connect(d->m_process, SIGNAL(lineReadyStandardOutput()), this, SLOT(decryptFileProcess()));
 	connect(d->m_process, SIGNAL(finished(int, QProcess::ExitStatus)), this, SLOT(decryptFileFin(int, QProcess::ExitStatus)));
@@ -560,21 +441,21 @@ KGpgTextInterface::decryptFileProcess()
 			} else if (line.startsWith("USERID_HINT")) {
 				d->updateIDs(line);
 			} else if (line.startsWith("ENC_TO")) {
-				if (line.contains("0000000000000000"))
+				if (line.contains( "0000000000000000" ))
 					d->m_anonymous = true;
 			} else if (line.startsWith("GET_")) {
-				if (line.contains("openfile.overwrite.okay")) {
+				if (line.contains( "openfile.overwrite.okay" )) {
 					d->m_process->write("Yes\n");
-				} else if ((line.contains("passphrase.enter"))) {
+				} else if ((line.contains( "passphrase.enter" ))) {
 					if (d->gpgPassphrase()) {
-						emit decryptFileFinished(1, this);
+						emit decryptFileFinished(1);
 						return;
 					}
 				} else {
 					d->m_process->write("quit\n");
 				}
 			} else {
-				d->m_message += line + '\n';
+				d->m_message += QLatin1String( line ) + QLatin1Char( '\n' );
 			}
 		}
 	}
@@ -587,21 +468,21 @@ KGpgTextInterface::decryptFileFin(int res, QProcess::ExitStatus status)
 	if (status == QProcess::CrashExit) {
 		if (d->m_dest.isLocalFile())
 			QFile(d->m_dest.toLocalFile()).remove();
-		emit decryptFileFinished(2, this);
+		emit decryptFileFinished(2);
 		return;
 	}
 
 	if (res != 0) {
 		if (d->m_dest.isLocalFile())
 			QFile(d->m_dest.toLocalFile()).remove();
-		emit decryptFileFinished(3, this);
+		emit decryptFileFinished(3);
 		return;
 	}
 
-	if (d->m_message.contains("DECRYPTION_OKAY") && d->m_message.contains("END_DECRYPTION"))
-		emit decryptFileFinished(0, this);
+	if (d->m_message.contains(QLatin1String( "DECRYPTION_OKAY" )) && d->m_message.contains( QLatin1String( "END_DECRYPTION" )))
+		emit decryptFileFinished(0);
 	else
-		emit decryptFileFinished(4, this);
+		emit decryptFileFinished(4);
 }
 
 void
@@ -609,13 +490,13 @@ KGpgTextInterface::KgpgVerifyFile(const KUrl &sigUrl, const KUrl &srcUrl)
 {
 	d->m_file = sigUrl;
 
-	*d->m_process << "--verify";
+	*d->m_process << QLatin1String( "--verify" );
 	if (!srcUrl.isEmpty())
 		*d->m_process << srcUrl.path();
 	*d->m_process << sigUrl.path();
 
 	connect(d->m_process, SIGNAL(lineReadyStandardOutput()), this, SLOT(readVerify()));
-	connect(d->m_process, SIGNAL(processExited(GPGProc *)), this, SLOT(verifyfin()));
+	connect(d->m_process, SIGNAL(processExited()), this, SLOT(verifyfin()));
 	d->m_process->start();
 }
 
@@ -626,8 +507,8 @@ KGpgTextInterface::readVerify()
 	QByteArray line;
 
 	while (d->m_process->readLineStandardOutput(&line)) {
-		d->m_message += GPGProc::recode(line) + '\n';
-		if (line.contains("GET_"))
+		d->m_message += GPGProc::recode(line) + QLatin1Char( '\n' );
+		if (line.contains( "GET_" ))
 			d->m_process->write("quit\n");
 
 		if (!line.startsWith("[GNUPG:] "))
@@ -636,18 +517,18 @@ KGpgTextInterface::readVerify()
 		if (line.startsWith("UNEXPECTED") || line.startsWith("NODATA")) {
 			d->m_signID = i18n("No signature found.");
 		} else if (line.startsWith("GOODSIG")) {
-			int sigpos = line.indexOf(' ', 8);
+			int sigpos = line.indexOf( ' ' , 8);
 			d->m_signID = i18n("<qt>Good signature from:<br /><b>%1</b><br />Key ID: %2<br /></qt>",
 					GPGProc::recode(line.mid(sigpos + 1).replace('<', "&lt;")),
 					QString::fromAscii(line.mid(8, sigpos - 8)));
 		} else if (line.startsWith("BADSIG")) {
-			int sigpos = line.indexOf(' ', 7);
+			int sigpos = line.indexOf( ' ', 7);
 			d->m_signID = i18n("<qt><b>BAD signature</b> from:<br /> %1<br />Key id: %2<br /><br /><b>The file is corrupted</b><br /></qt>",
 					GPGProc::recode(line.mid(sigpos + 1).replace('<', "&lt;")),
 					QString::fromAscii(line.mid(7, sigpos - 7)));
 		} else if (line.startsWith("NO_PUBKEY")) {
 			d->m_signmiss = true;
-			d->m_signID = line.remove(0, line.indexOf(' '));
+			d->m_signID = QLatin1String( line.remove(0, line.indexOf( ' ' )) );
 		} else  if (line.startsWith("TRUST_UNDEFINED")) {
 			d->m_signID += i18n("<qt>The signature is valid, but the key is untrusted<br /></qt>");
 		} else if (line.startsWith("TRUST_ULTIMATE")) {
@@ -664,7 +545,8 @@ KGpgTextInterface::verifyfin()
 		if (d->m_signID.isEmpty())
 			d->m_signID = i18n("No signature found.");
 
-		(void) new KgpgDetailedInfo(0, d->m_signID, d->m_message);
+		(void) new KgpgDetailedInfo(qobject_cast<QWidget *>(parent()), d->m_signID, d->m_message,
+				QStringList(), i18nc("Caption of message box", "Verification Finished"));
 	} else {
 		if (KMessageBox::questionYesNo(0,
 					i18n("<qt><b>Missing signature:</b><br />Key id: %1<br /><br />Do you want to import this key from a keyserver?</qt>", d->m_signID),
@@ -692,8 +574,8 @@ KGpgTextInterface::signFilesBlocking(const QString &keyID, const KUrl::List &src
 	d->m_signID = keyID;
 	d->m_gpgopts = options;
 
-	for (int i = 0; i < srcUrls.count(); i++) {
-		d->signFile(srcUrls.at(i));
+	foreach (const KUrl &url, srcUrls) {
+		d->signFile(url);
 		d->m_process->waitForFinished(-1);
 		d->m_process->resetProcess();
 	}
@@ -722,5 +604,5 @@ KGpgTextInterface::slotSignFinished(int err)
 	if (err != 0)
 		d->m_errfiles << d->m_files.at(d->m_step - 1);
 
-	emit fileSignFinished(this, d->m_errfiles);
+	emit fileSignFinished(d->m_errfiles);
 }
