@@ -1,4 +1,4 @@
-/**
+/*
  * Copyright (C) 2008,2009 Rolf Eike Beer <kde@opensource.sf-tec.de>
  */
 
@@ -19,11 +19,12 @@
 #include "kgpgtransaction.h"
 
 /**
- * \brief set a new passphrase for a key pair
+ * @brief set a new passphrase for a key pair
  */
 class KGpgChangePass: public KGpgTransaction {
 	Q_OBJECT
 
+	Q_DISABLE_COPY(KGpgChangePass)
 public:
 	KGpgChangePass(QObject *parent, const QString &keyid);
 	virtual ~KGpgChangePass();
