@@ -1,4 +1,4 @@
-/**
+/*
  * Copyright (C) 2008,2009 Rolf Eike Beer <kde@opensource.sf-tec.de>
  */
 
@@ -13,22 +13,19 @@
 
 #include "kgpguidtransaction.h"
 
-KGpgUidTransaction::KGpgUidTransaction(QObject *parent)
-	: KGpgTransaction(parent)
-{
-	Q_ASSERT(false);
-}
-
 KGpgUidTransaction::KGpgUidTransaction(QObject *parent, const QString &keyid, const QString &uid)
 	: KGpgTransaction(parent)
 {
-	addArgument("--status-fd=1");
-	addArgument("--command-fd=0");
-	addArgument("--edit-key");
-	addArgument(keyid);
-	addArgument("uid");
+	addArgument(QLatin1String( "--status-fd=1" ));
+	addArgument(QLatin1String( "--command-fd=0" ));
+	addArgument(QLatin1String( "--edit-key" ));
+	m_keyidpos = addArgument(QString());
+	addArgumentRef(&m_keyidpos);
+	addArgument(QLatin1String( "uid" ));
 	m_uidpos = addArgument(QString());
+	addArgumentRef(&m_uidpos);
 
+	setKeyId(keyid);
 	setUid(uid);
 }
 
@@ -47,26 +44,41 @@ KGpgUidTransaction::preStart()
 bool
 KGpgUidTransaction::standardCommands(const QString &line)
 {
-	if (!line.startsWith("[GNUPG:] "))
+	if (!line.startsWith(QLatin1String("[GNUPG:] ")))
 		return false;
 
-	if (line.contains("GOOD_PASSPHRASE")) {
+	if (line.contains(QLatin1String( "GOOD_PASSPHRASE" ))) {
 		setSuccess(TS_MSG_SEQUENCE);
-	} else if (line.contains("passphrase.enter")) {
+	} else if (line.contains(QLatin1String( "passphrase.enter" ))) {
 		if (askPassphrase())
 			setSuccess(TS_USER_ABORTED);
-	} else if (line.contains("keyedit.prompt")) {
+	} else if (line.contains(QLatin1String( "keyedit.prompt" ))) {
 		write("save");
-		setSuccess(TS_OK);
-	} else if (line.contains("GET_")) {
+		if (getSuccess() == TS_MSG_SEQUENCE)
+			setSuccess(TS_OK);
+		return true;
+	} else if (line.contains(QLatin1String( "GET_" ))) {
 		setSuccess(TS_MSG_SEQUENCE);
-		// gpg asks for something unusal, turn to konsole mode
 		return true;
 	}
 
 	return false;
 }
 
+void
+KGpgUidTransaction::setKeyId(const QString &keyid)
+{
+	m_keyid = keyid;
+
+	replaceArgument(m_keyidpos, keyid);
+}
+
+QString
+KGpgUidTransaction::getKeyId(void) const
+{
+	return m_keyid;
+}
+
 void
 KGpgUidTransaction::setUid(const QString &uid)
 {
